package cn.estsh.i3plus.pojo.mes.sqlpack;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.MesEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesPart;
import cn.estsh.i3plus.pojo.mes.bean.MesPlanOrder;
import cn.estsh.i3plus.pojo.mes.bean.MesQueueOrder;
import cn.estsh.i3plus.pojo.mes.bean.MesWorkOrder;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description:
 * @Reference: Mes 条件封装
 * @Author: Crish
 * @CreateDate:2019-04-22-14:58
 * @Modify:
 **/
public class MesHqlPack {

    /**
     * 通用查询条件
     * @param organizeCode
     * @return
     */
    public static DdlPackBean getAllBaseData(String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);
        return packBean;
    }

    /**
     * 生产计划查询条件封装
     * @param mesPlanOrder
     * @return
     */
    public static DdlPackBean getPlanOrderCondition(MesPlanOrder mesPlanOrder, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);

        if (StringUtils.isNotEmpty(mesPlanOrder.getOrderNo())) {
            DdlPreparedPack.getStringEqualPack(mesPlanOrder.getOrderNo(), "orderNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getPartNo())) {
            DdlPreparedPack.getStringEqualPack(mesPlanOrder.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getPlanType() + "") && mesPlanOrder.getPlanTypeVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesPlanOrder.getPlanType(), "planType", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getStatus() + "") && mesPlanOrder.getStatusVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesPlanOrder.getStatus(), "status", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getCreateUser())) {
            DdlPreparedPack.getStringEqualPack(mesPlanOrder.getCreateUser(), "createUser", packBean);
        }

        // 时间段查询
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getStartTimeStart(),
                mesPlanOrder.getStartTimeEnd(),
                "startTime", packBean, true);
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getEndTimeStart(),
                mesPlanOrder.getEndTimeEnd(),
                "endTime", packBean, true);
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getCreateDateTimeStart(),
                mesPlanOrder.getCreateDateTimeEnd(),
                "createDatetime", packBean, true);

        // 排序
         DdlPreparedPack.getOrderDefault(mesPlanOrder);
         DdlPreparedPack.getOrderByPack(new Object[]{"2"},new String[]{mesPlanOrder.getOrderByParam()} , packBean);
        return packBean;
    }

    /**
     * 物料信息查询条件封装
     * @param mesPart
     * @return
     */
    public static DdlPackBean getPartCondition(MesPart mesPart, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);

        if (StringUtils.isNotEmpty(mesPart.getPartNo())) {
            DdlPreparedPack.getStringLikerPack(mesPart.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getPartName())) {
            DdlPreparedPack.getStringLikerPack(mesPart.getPartName(), "partName", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode1())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode1(), "categoryCode1", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode2())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode2(), "categoryCode2", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode3())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode3(), "categoryCode3", packBean);
        }

        DdlPreparedPack.getOrderDefault(mesPart);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"},new String[]{mesPart.getOrderByParam()} , packBean);
        return packBean;
    }

    /**
     * 生产工单查询条件封装
     * @param mesWorkOrder
     * @return
     */
    public static DdlPackBean getWorkOrderCondition(MesWorkOrder mesWorkOrder, String organizeCode) {
        DdlPackBean packBean = getAllBaseData(organizeCode);
        if (StringUtils.isNotEmpty(mesWorkOrder.getOrderNo())) {
            DdlPreparedPack.getStringLikerPack(mesWorkOrder.getOrderNo(), "orderNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getPartNo())) {
            DdlPreparedPack.getStringLikerPack(mesWorkOrder.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkOrderStatus() + "") && mesWorkOrder.getWorkOrderStatusVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesWorkOrder.getWorkOrderStatus(), "workOrderStatus", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkCellCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkOrderType() + "") && mesWorkOrder.getWorkOrderTypeVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesWorkOrder.getWorkOrderType(), "workOrderType", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getProdCfgCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getProdCfgCode(), "prodCfgCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getPlanOrderNo())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getPlanOrderNo(), "planOrderNo", packBean);
        }

        // 时间段查询
//        DdlPreparedPack.timeBuilder(
//                mesWorkOrder.getStartTimeStart(),
//                mesWorkOrder.getStartTimeEnd(),
//                "startTime", packBean, true);
//        DdlPreparedPack.timeBuilder(
//                mesWorkOrder.getEndTimeStart(),
//                mesWorkOrder.getEndTimeEnd(),
//                "endTime", packBean, true);
        DdlPreparedPack.getOrderDefault(mesWorkOrder);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"},new String[]{mesWorkOrder.getOrderByParam()} , packBean);
        return packBean;
    }

    /**
     * 生产队列查询条件封装
     * @param mesQueueOrder
     * @return
     */
    public static DdlPackBean getQueueOrder(MesQueueOrder mesQueueOrder, String organizeCode) {
        DdlPackBean packBean = getAllBaseData(organizeCode);
        if (StringUtils.isNotEmpty(mesQueueOrder.getCustFlagNoStart())) {
            DdlPreparedPack.getStringBiggerPack(mesQueueOrder.getCustFlagNoStart(), "custFlagNo", packBean);
        }

        if (StringUtils.isNotEmpty(mesQueueOrder.getCustFlagNoEnd() + "")) {
            DdlPreparedPack.getStringSmallerPack(mesQueueOrder.getCustFlagNoEnd(), "custFlagNo", packBean);
        }
        DdlPreparedPack.getNumEqualPack(MesEnumUtil.QUEUE_ORDER_STATUS.NORMAL.getValue(), "status", packBean);
        // 时间段查询
        DdlPreparedPack.timeBuilder(
                mesQueueOrder.getCreateDateTimeStart(),
                mesQueueOrder.getCreateDateTimeEnd(),
                "createDatetime", packBean, true);

        DdlPreparedPack.getOrderDefault(mesQueueOrder);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"},new String[]{mesQueueOrder.getOrderByParam()} , packBean);
        return packBean;
    }
}
